@@ -1,32 +1,21 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2006 Daniel Teske <teske@squorn.de>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2006 Daniel Teske <teske@squorn.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kbookmarkaction.h"
 #include "kbookmarkowner.h"
-#include <QDesktopServices>
+
 #include <QApplication>
+#include <QDesktopServices>
 
 KBookmarkAction::KBookmarkAction(const KBookmark &bk, KBookmarkOwner *owner, QObject *parent)
-    : QAction(bk.text().replace('&', QLatin1String("&&")), parent),
-      KBookmarkActionInterface(bk),
-      m_pOwner(owner)
+    : QAction(bk.text().replace(QLatin1Char('&'), QLatin1String("&&")), parent)
+    , KBookmarkActionInterface(bk)
+    , m_pOwner(owner)
 {
     setIcon(QIcon::fromTheme(bookmark().icon()));
     setIconText(text());
@@ -57,4 +46,3 @@ void KBookmarkAction::slotSelected(Qt::MouseButtons mb, Qt::KeyboardModifiers km
         m_pOwner->openBookmark(bookmark(), mb, km);
     }
 }
-
